bayespy.nodes.GaussianWishart.initialize_from_parameters
========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianWishart.initialize_from_parameters